<?php

namespace App\Console\Commands\Star;

use App\Models\JxStarLiveOrderList;
use App\Models\JxStarLiveTaskList;
use App\Models\JxStarUsers;
use App\Services\RdsLockService;
use App\Support\Log;
use App\Support\RedisModel;
use Illuminate\Console\Command;

class LiveOrderDataInDb extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'Star:LiveOrderDataInDb';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '星直播订单数据入库';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $this->info(date('H:i') . ' 开始执行');
        $this->start();
        $this->info(date('H:i') . ' 结束执行');

        return 0;
    }

    public function start()
    {
        $curTime = time();
        while (true) {
            if ((time() - $curTime) >= 60) break;

            $dataJson = RedisModel::rPop(JxStarLiveOrderList::JUXING_STAR_LIVE_ORDER_INDB_LIST);
            if (empty($dataJson)) {
                sleep(2);
                continue;
            }

            $data = json_decode($dataJson, true);
            if (!isset($data['advertiser_id'], $data['task_id'], $data['data'])) {
                # 输出错误日志
                Log::error('数据参数不合法', $data, 'Star:LiveOrderDataInDb');
                continue;
            }

            $this->orderDataInDb($data);
        }
    }

    public function orderDataInDb($data)
    {
        $advertiserId = $data['advertiser_id'];
        $taskId       = $data['task_id'];
        $dataVal      = $data['data'];

        $orderId = $dataVal['order_id'] ?? null;
        if (empty($orderId)) {
            # 输出错误日志
            Log::error('orderId 为空', $data, 'Star:LiveOrderDataInDb');
            return false;
        }

        $lockKey = RdsLockService::getRdsLockKey([
            'starLive', $advertiserId, $taskId, $orderId
        ]);


        $realAmount = $dataVal['real_amount'] ?? 0;
        $playCnt    = $dataVal['play_cnt'] ?? 0;
        $playUv     = $dataVal['play_uv'] ?? 0;

        if (RdsLockService::addRdsLock($lockKey)) {
            $orderInfo = JxStarLiveOrderList::query()
                ->where('advertiser_id', $advertiserId)
                ->where('task_id', $taskId)
                ->where('order_id', $orderId)
                ->where('enable', 1)
                ->first();
            if (empty($orderInfo)) {
                $orderInfo = new JxStarLiveOrderList([
                    'advertiser_id' => $advertiserId,
                    'task_id'       => $taskId,
                    'order_id'      => $orderId
                ]);
            } else {
                if (
                    ($realAmount < $orderInfo->real_amount)
                    ||
                    ($playCnt < $orderInfo->play_cnt)
                    ||
                    ($playUv < $orderInfo->play_uv)
                )
                {
                    # 输出错误日志
                    Log::error('adv:'.$advertiserId.' 返回数据存在异常', $dataVal, 'Star:LiveOrderDataInDb');
                    return false;
                }
            }

            $orderInfo->order_type                 = $dataVal['order_type'] ?? null;
            $orderInfo->amount                     = $dataVal['amount'] ?? 0;
            $orderInfo->star_amount                = $dataVal['star_amount'] ?? 0;
            $orderInfo->star_name                  = $dataVal['star_name'] ?? null;
            $orderInfo->kwai_id                    = $dataVal['kwai_id'] ?? null;
            $orderInfo->user_id                    = $dataVal['user_id'] ?? null;
            $orderInfo->play_cnt                   = $playCnt;
            $orderInfo->play_uv                    = $playUv;
            $orderInfo->like_cnt                   = $dataVal['like_cnt'] ?? 0;
            $orderInfo->comment_cnt                = $dataVal['comment_cnt'] ?? 0;
            $orderInfo->share_cnt                  = $dataVal['share_cnt'] ?? 0;
            $orderInfo->real_amount                = $realAmount;
            $orderInfo->live_start_time            = $dataVal['live_start_time'] ?? null;
            $orderInfo->star_settlement_flag       = $dataVal['star_settlement_flag'] ?? null;
            $orderInfo->star_bind_institution_flag = $dataVal['star_bind_institution_flag'] ?? null;

            # 汇总直播数据
            $orderInfo->live_duration    = $dataVal['live_duration'];
            $orderInfo->item_show_cnt    = $dataVal['item_show_cnt'];
            $orderInfo->item_click_cnt   = $dataVal['item_click_cnt'];
            $orderInfo->sale_product_cnt = $dataVal['sale_product_cnt'];
            $orderInfo->sale_amount      = $dataVal['sale_amount'];

            $orderInfo->save();

            RdsLockService::delRdsLock($lockKey);

            ## 获取达人信息队列
            JxStarUsers::intoUserInfoSyncRds($orderInfo->user_id);
        }

//        Log::info('订单数据入库成功', ['orderId' => $orderId], 'Star:LiveOrderDataInDb');

        return 0;
    }
}
