<?php

namespace App\Console\Commands\Star;

use App\Models\JxStarUsers;
use App\Models\JxStarVideoOrderList;
use App\Services\RdsLockService;
use App\Support\Log;
use App\Support\RedisModel;
use Illuminate\Console\Command;

class VideoOrderDataInDb extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'Star:VideoOrderDataInDb';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '星视频订单数据入库';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $this->info(date('H:i') . ' 开始执行');
        $this->start();
        $this->info(date('H:i') . ' 结束执行');

        return 0;
    }

    public function start()
    {
        $curTime = time();
        while (true) {
            if ((time() - $curTime) >= 60) break;

            $dataJson = RedisModel::rPop(JxStarVideoOrderList::JUXING_STAR_VIDEO_ORDER_INDB_LIST);
            if (empty($dataJson)) {
                sleep(2);
                continue;
            }

            $data = json_decode($dataJson, true);
            if (!isset($data['advertiser_id'], $data['task_id'], $data['data'])) {
                # 输出错误日志
                Log::error('数据参数不合法', $data, 'Star:VideoOrderDataInDb');
                continue;
            }

            $this->orderDataInDb($data);
        }
    }

    public function orderDataInDb($data)
    {
        $advertiserId = $data['advertiser_id'];
        $taskId       = $data['task_id'];
        $dataVal      = $data['data'];

        $orderId = $dataVal['order_id'] ?? null;
        if (empty($orderId)) {
            # 输出错误日志
            Log::error('orderId 为空', $data, 'Star:VideoOrderDataInDb');
            return false;
        }

        $lockKey = RdsLockService::getRdsLockKey([
            'starVideo', $advertiserId, $taskId, $orderId
        ]);

        $realAmount = $dataVal['real_amount'] ?? 0;
        $play       = $dataVal['play'] ?? 0;
        $action     = $dataVal['action'] ?? 0;

        if (RdsLockService::addRdsLock($lockKey)) {
            $orderInfo = JxStarVideoOrderList::query()
                ->where('advertiser_id', $advertiserId)
                ->where('task_id', $taskId)
                ->where('order_id', $orderId)
                ->where('enable', 1)
                ->first();
            if (empty($orderInfo)) {
                $orderInfo = new JxStarVideoOrderList([
                    'advertiser_id' => $advertiserId,
                    'task_id'       => $taskId,
                    'order_id'      => $orderId
                ]);
            } else {
                if (
                    ($realAmount < $orderInfo->real_amount)
                    ||
                    ($play < $orderInfo->play)
                    ||
                    ($action < $orderInfo->action)
                )
                {
                    # 输出错误日志
                    Log::error('adv:'.$advertiserId.' 返回数据存在异常', $dataVal, 'Star:VideoOrderDataInDb');
                    return false;
                }
            }

            $orderInfo->order_status         = $dataVal['order_status'] ?? null;
            $orderInfo->order_type           = $dataVal['order_type'] ?? null;
            $orderInfo->amount               = $dataVal['amount'] ?? null;
            $orderInfo->star_amount          = $dataVal['star_amount'] ?? null;
            $orderInfo->top_amount           = $dataVal['top_amount'] ?? null;
            $orderInfo->link_amount          = $dataVal['link_amount'] ?? null;
            $orderInfo->peak_flow_amount     = $dataVal['peak_flow_amount'] ?? null;
            $orderInfo->star_name            = $dataVal['star_name'] ?? null;
            $orderInfo->kwai_id              = $dataVal['kwai_id'] ?? null;
            $orderInfo->user_id              = $dataVal['user_id'] ?? null;
            $orderInfo->star_release_time    = $dataVal['star_release_time'] ?? null;
            $orderInfo->support_supplement   = $dataVal['support_supplement'] ?? null;
            $orderInfo->has_supplement       = $dataVal['has_supplement'] ?? null;
            $orderInfo->caption              = $dataVal['caption'] ?? null;
            $orderInfo->video_url            = $dataVal['video_url'] ?? null;
            $orderInfo->star_status          = $dataVal['star_status'] ?? null;
            $orderInfo->star_institution     = $dataVal['star_institution'] ?? null;
            $orderInfo->video_status         = $dataVal['video_status'] ?? null;
            $orderInfo->real_amount          = $realAmount;
            $orderInfo->view                 = $dataVal['view'] ?? 0;
            $orderInfo->play                 = $play;
            $orderInfo->action               = $action;
            $orderInfo->admire               = $dataVal['admire'] ?? 0;
            $orderInfo->comment              = $dataVal['comment'] ?? 0;
            $orderInfo->click_rate           = $dataVal['click_rate'] ?? 0;
            $orderInfo->play_5s_rate         = $dataVal['play_5s_rate'] ?? 0;
            $orderInfo->play_end_rate        = $dataVal['play_end_rate'] ?? 0;
            $orderInfo->item_impression_cnt  = $dataVal['item_impression_cnt'] ?? 0;
            $orderInfo->item_click_cnt       = $dataVal['item_click_cnt'] ?? 0;
            $orderInfo->item_click_rate      = $dataVal['item_click_rate'] ?? 0;
            $orderInfo->user_cnt             = $dataVal['user_cnt'] ?? 0;
            $orderInfo->age_percentage_v2    = isset($dataVal['age_percentage_v2'])
                ? json_encode($dataVal['age_percentage_v2']) : null;
            $orderInfo->interest_percentage  = isset($dataVal['interest_percentage'])
                ? json_encode($dataVal['interest_percentage']) : null;
            $orderInfo->active_percentage_v2 = isset($dataVal['active_percentage_v2'])
                ? json_encode($dataVal['active_percentage_v2']) : null;
            $orderInfo->mobie_percentage     = isset($dataVal['mobie_percentage'])
                ? json_encode($dataVal['mobie_percentage']) : null;
            $orderInfo->gender_percentage    = isset($dataVal['gender_percentage'])
                ? json_encode($dataVal['gender_percentage']) : null;
            $orderInfo->area_percentage      = isset($dataVal['area_percentage'])
                ? json_encode($dataVal['area_percentage']) : null;
            $orderInfo->emotion_percentage   = isset($dataVal['emotion_percentage'])
                ? json_encode($dataVal['emotion_percentage']) : null;

            # 反向计算得出
            $orderInfo->click    = ceil($orderInfo->view * $orderInfo->click_rate);
            $orderInfo->play_5s  = ceil($orderInfo->view * $orderInfo->play_5s_rate);
            $orderInfo->play_end = ceil($orderInfo->view * $orderInfo->play_end_rate);

            $orderInfo->save();

            RdsLockService::delRdsLock($lockKey);

            ## 获取达人信息队列
            JxStarUsers::intoUserInfoSyncRds($orderInfo->user_id);
        }

//        Log::info('订单数据入库成功', ['orderId' => $orderId], 'Star:VideoOrderDataInDb');
        return 0;
    }
}
