<?php

namespace App\Http\Controllers\Api\Data;

use App\Http\Controllers\Controller;
use App\Services\Data\CustomerService;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;

class CustomerController extends Controller
{
    /**
     * 客户分析-汇总和曲线
     * @param Request $request
     * @return array
     */
    public function summaryTrend(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'advertiser_ids' => 'nullable|array',
            'st_date'        => 'required|date_format:Y-m-d',
            'en_date'        => 'required|date_format:Y-m-d'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $advertiserIds = $request->input('advertiser_ids');
        $stDate        = $request->input('st_date');
        $enDate        = $request->input('en_date');

        $res = CustomerService::summaryTrend($advertiserIds, $stDate, $enDate);
        return self::returnValue($res);
    }

    /**
     * 客户分析-数据列表
     * @param Request $request
     * @return array
     */
    public function dataList(Request $request)
    {
        $prTypeArr = ["starVideo", "starLive", "qtaskVideo", "qtaskLive", "flowStarVideo", "flowStarLive", "flowQtaskVideo"];
        $validator = \Validator::make($request->all(),[
            'pr_type'        => ['required', Rule::in($prTypeArr)],
            'advertiser_ids' => 'nullable|array',
            'st_date'        => 'required|date_format:Y-m-d',
            'en_date'        => 'required|date_format:Y-m-d'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $prType        = $request->input('pr_type');
        $advertiserIds = $request->input('advertiser_ids');
        $stDate        = $request->input('st_date');
        $enDate        = $request->input('en_date');

        $res = CustomerService::dataList($prType, $advertiserIds, $stDate, $enDate);
        return self::returnValue($res);
    }
}
