<?php

namespace App\Http\Controllers\Api\Data;

use App\Services\Data\DataStatService;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;

class DataStatController extends Controller
{
    public function redVideoRank(Request $request)
    {
        $columns = [
            'amount',
            'view',
            'play',
            'action',
            'admire',
            'comment',
            'click_rate',
            'click_cnt',
            'play_5s_rate',
            'play_end_rate',
            'item_impression_cnt',
            'item_click_cnt',
            'item_click_rate',
            'cpm',  // 千次播放成本
            'cpc',  // 点击成本
            'cpa',  // 激活成本/注册成本
        ];
        $validator = \Validator::make($request->all(),[
            'day' => ['required', Rule::in([7, 30, 60, 90, 180])],
            'flag' => ['required', Rule::in(['min', 'max'])],
            'column' => ['required', Rule::in($columns)]
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $day = $request->input('day');
        $column = $request->input('column');
        $flag = $request->input('flag');
        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::redVideoRank($day, $column, $flag, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function redLiveRank(Request $request)
    {
        $columns = [
            'amount', //消耗
            'play_cnt',
            'play_uv',
            'like_cnt',
            'comment_cnt',
            'share_cnt',
            'item_show_cnt',
            'item_click_cnt',
            'item_click_rate',
            'cpm',  // 千次播放成本
            'cpa',  // 激活成本/注册成本
        ];

        $validator = \Validator::make($request->all(),[
            'day' => ['required', Rule::in([7, 30, 60, 90, 180])],
            'flag' => ['required', Rule::in(['min', 'max'])],
            'column' => ['required', Rule::in($columns)]
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $day = $request->input('day');
        $column = $request->input('column');
        $flag = $request->input('flag');
        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::redLiveRank($day, $column, $flag, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function costDataTotal(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');

        $data = DataStatService::costTotal($st_date, $en_date);

        return self::returnValue($data);
    }

    public function custCostList(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in(['totalCost', 'starVideoCost', 'starLiveCost', 'qTaskCost', 'flowCost'])],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'totalCost');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custCostLists($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custFlowVideoList(Request $request)
    {
        $columns = [
            'consume_amount',
            'play',
            'action',         //行为数
            'conversion',     //激活数
            'comment',
            'admire',
            'played3s_cnt',
            'played3s_percent',
            'ctr',
            'cpm',
            'cpc',
            'cpa'
        ];

        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in($columns)],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'consume_amount');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custFlowVideoList($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custFlowVideoDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $cust_id = $request->input('cust_id');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custFlowVideoDetails($st_date, $en_date, $cust_id, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custFlowVideoUserDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');

        $data = DataStatService::custFlowVideoUserDetails($date, $cust_id);

        return self::returnValue($data);
    }

    public function custFlowLiveList(Request $request)
    {
        $columns = [
            'consume_amount',
            'audience_num',   //引入观众数
            'played3s_num',    //观看3秒+观众数
            'fans_increase_num',  //涨粉数
            'item_impression_num',  //推广直播间曝光数
            'interactive_num',      //互动数
            'conversion_impression_num', //组件曝光数
            'conversion_action_num',   //行为数
            'cash_amount',
            'client_amount',
            'agency_amount',
            'credit_consume_amount',
            'ctr',
            'cpa'
        ];

        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in($columns)],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'consume_amount');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custFlowLiveList($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custFlowLiveDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $cust_id = $request->input('cust_id');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custFlowLiveDetails($st_date, $en_date, $cust_id, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custFlowLiveUserDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');

        $data = DataStatService::custFlowLiveUserDetails($date, $cust_id);

        return self::returnValue($data);
    }

    public function industryFlowVideoList(Request $request)
    {
        $columns = [
            'consume_amount',
            'play',
            'action',         //行为数
            'conversion',     //激活数
            'comment',
            'admire',
            'played3s_cnt',
            'played3s_percent',
            'ctr',
            'cpm',
            'cpc',
            'cpa'
        ];

        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in($columns)],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'consume_amount');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::industryFlowVideoList($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function industryFlowVideoDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'industry_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $industry_id = $request->input('industry_id');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::industryFlowVideoDetails($st_date, $en_date, $industry_id, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function industryFlowVideoCustDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'industry_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $industry_id = $request->input('industry_id');

        $data = DataStatService::industryFlowVideoCustDetails($date, $industry_id);

        return self::returnValue($data);
    }

    public function industryFlowLiveList(Request $request)
    {
        $columns = [
            'consume_amount',
            'audience_num',   //引入观众数
            'played3s_num',    //观看3秒+观众数
            'fans_increase_num',  //涨粉数
            'item_impression_num',  //推广直播间曝光数
            'interactive_num',      //互动数
            'conversion_impression_num', //组件曝光数
            'conversion_action_num',   //行为数
            'cash_amount',
            'client_amount',
            'agency_amount',
            'credit_consume_amount',
            'ctr',
            'cpa'
        ];

        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in($columns)],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'consume_amount');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::industryFlowLiveList($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function industryFlowLiveDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'industry_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $industry_id = $request->input('industry_id');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::industryFlowLiveDetails($st_date, $en_date, $industry_id, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function industryFlowLiveCustDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'industry_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $industry_id = $request->input('industry_id');

        $data = DataStatService::industryFlowLiveCustDetails($date, $industry_id);

        return self::returnValue($data);
    }

    public function svfDailyData(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'cust_id' => 'required|int',
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $cust_id = $request->input('cust_id');
        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::svfDailyData($cust_id, $st_date, $en_date, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function svfDailyUserData(Request $request)
    {
        $columns = ['consume_amount'];
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
            'sort'   => ['nullable', Rule::in($columns)],
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');
        $sort = $request->input('sort');

        $data = DataStatService::svfDailyUserData($cust_id, $date, $sort);

        return self::returnValue($data);
    }

    public function svfDataUp(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'cust_id'=> 'required|int'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $cust_id = $request->input('cust_id');

        $code = DataStatService::svfDataUp($cust_id);

        return self::returnValue('', $code);
    }

    public function qtaskVideoDailyData(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'cust_id' => 'required|int',
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $cust_id = $request->input('cust_id');
        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::qtaskVideoDailyData($cust_id, $st_date, $en_date, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function qtaskVideoTaskDailyData(Request $request)
    {
        $columns = ['cost'];
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
            'sort'   => ['nullable', Rule::in($columns)],
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');
        $sort = $request->input('sort');

        $data = DataStatService::qtaskVideoTaskDailyData($cust_id, $date, $sort);

        return self::returnValue($data);
    }

    public function qtaskVideoOrderDailyData(Request $request)
    {
        $columns = ['cost'];
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
            'task_id'=> 'required|string',
            'sort'   => ['nullable', Rule::in($columns)],
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');
        $task_id = $request->input('task_id');
        $sort = $request->input('sort');

        $data = DataStatService::qtaskVideoOrderDailyData($cust_id, $task_id, $date, $sort);

        return self::returnValue($data);
    }

    public function qtaskLiveDailyData(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'cust_id' => 'required|int',
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $cust_id = $request->input('cust_id');
        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::qtaskLiveDailyData($cust_id, $st_date, $en_date, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function qtaskLiveTaskDailyData(Request $request)
    {
        $columns = ['cost'];
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
            'sort'   => ['nullable', Rule::in($columns)],
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');
        $sort = $request->input('sort');

        $data = DataStatService::qtaskLiveTaskDailyData($cust_id, $date, $sort);

        return self::returnValue($data);
    }

    public function qtaskLiveOrderDailyData(Request $request)
    {
        $columns = ['cost'];
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
            'task_id'=> 'required|string',
            'sort'   => ['nullable', Rule::in($columns)],
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');
        $task_id = $request->input('task_id');
        $sort = $request->input('sort');

        $data = DataStatService::qtaskLiveOrderDailyData($cust_id, $task_id, $date, $sort);

        return self::returnValue($data);
    }

    public function industryQtaskVideoList(Request $request)
    {
        $columns = [
            'cost',
            'view',
            'play',
            'action',
            'admire',
            'comment',
            'item_impression_cnt',
            'item_click_cnt',
            'play_5s',
            'play_3s',
            'app_download',
            'conversion',
            'share_num',
            'ctr',
            'cpm',
            'cpc',
            'cpa'
        ];

        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in($columns)],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'cost');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::industryQtaskVideoList($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function industryQtaskVideoDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'industry_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $industry_id = $request->input('industry_id');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::industryQtaskVideoDetails($st_date, $en_date, $industry_id, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function industryQtaskVideoCustDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'industry_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $industry_id = $request->input('industry_id');

        $data = DataStatService::industryQtaskVideoCustDetails($date, $industry_id);

        return self::returnValue($data);
    }

    public function industryQtaskLiveList(Request $request)
    {
        $columns = [
            'cost',
            'item_impression_cnt',
            'item_click_cnt',
            'app_download',
            'conversion',
            'ctr',
            'cpc',
            'cpa'
        ];

        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in($columns)],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'cost');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::industryQtaskLiveList($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function industryQtaskLiveDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'industry_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $industry_id = $request->input('industry_id');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::industryQtaskLiveDetails($st_date, $en_date, $industry_id, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function industryQtaskLiveCustDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'industry_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $industry_id = $request->input('industry_id');

        $data = DataStatService::industryQtaskLiveCustDetails($date, $industry_id);

        return self::returnValue($data);
    }

    public function custQtaskVideoList(Request $request)
    {
        $columns = [
            'cost',
            'view',
            'play',
            'action',
            'admire',
            'comment',
            'item_impression_cnt',
            'item_click_cnt',
            'play_5s',
            'play_3s',
            'app_download',
            'conversion',
            'share_num',
            'ctr',
            'cpm',
            'cpc',
            'cpa'
        ];

        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in($columns)],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'cost');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custQtaskVideoList($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custQtaskVideoDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $cust_id = $request->input('cust_id');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custQtaskVideoDetails($st_date, $en_date, $cust_id, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custQtaskVideoUserDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');

        $data = DataStatService::custQtaskVideoUserDetails($date, $cust_id);

        return self::returnValue($data);
    }

    public function custQtaskLiveList(Request $request)
    {
        $columns = [
            'cost',
            'item_impression_cnt',
            'item_click_cnt',
            'app_download',
            'conversion',
            'ctr',
            'cpc',
            'cpa'
        ];

        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'sort'    => ['nullable', Rule::in($columns)],
            'sort_type'=> 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $sort = $request->input('sort', 'cost');
        $sort_type = $request->input('sort_type', 0);

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custQtaskLiveList($st_date, $en_date, $sort, $sort_type, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custQtaskLiveDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $st_date = $request->input('st_date');
        $en_date = $request->input('en_date');
        $cust_id = $request->input('cust_id');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = DataStatService::custQtaskLiveDetails($st_date, $en_date, $cust_id, $page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function custQtaskLiveUserDetails(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'date' => 'required|date_format:Y-m-d',
            'cust_id'=> 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $date = $request->input('date');
        $cust_id = $request->input('cust_id');

        $data = DataStatService::custQtaskLiveUserDetails($date, $cust_id);

        return self::returnValue($data);
    }

    # 助推订单列表
    public function supplementOrderList(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'nullable|date_format:Y-m-d',
            'en_date' => 'nullable|date_format:Y-m-d',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $stDate = $request->input('st_date');
        $enDate = $request->input('en_date');
        $keyword = $request->input('keyword');
        $type = $request->input('type');
        $custId = $request->input('cust_id');
        $status = $request->input('status');

        $page = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);
        $sortField = $request->input('sort_field', 'promotion_begin_time');
        $sortType = $request->input('sort_type', 'desc');

        list($list, $count) = DataStatService::supplementOrderList($custId, $stDate, $enDate, $keyword, $type, $status, $sortField, $sortType, $page, $pageSize);
        return self::returnPageValue($list, $count, $pageSize, $page);
    }

    # 分时数据趋势
    public function svfHourDataCure(Request $request) {
        $validator = \Validator::make($request->all(),[
            'cust_id' => 'required',
            'start_time' => 'required|date_format:Y-m-d H:i:s',
            'end_time' => 'required|date_format:Y-m-d H:i:s',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $custId = $request->input('cust_id');
        $startTime = $request->input('start_time');
        $endTime = $request->input('end_time');
        $data = DataStatService::svfHourDataCure($custId, $startTime, $endTime);
        return self::returnValue($data);
    }

    # 分时数据对比
    public function svfHourDataContrast(Request $request) {
        $validator = \Validator::make($request->all(),[
            'cust_id' => 'required',
            'period' => 'required',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $custId = $request->input('cust_id');
        $period = $request->input('period');
        $data = DataStatService::svfHourDataContrast($custId, $period);
        return self::returnValue($data);
    }
}
