<?php

namespace App\Http\Controllers\Api\Data;

use App\Http\Controllers\Controller;
use App\Services\Data\ProductService;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;

class ProductController extends Controller
{
    /**
     * 产品分析-消耗汇总
     * @param Request $request
     * @return array
     */
    public function dataSummary(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'cust_id' => 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $custId = $request->input('cust_id');
        $stDate = $request->input('st_date');
        $enDate = $request->input('en_date');

        $res = ProductService::dataSummary($custId, $stDate, $enDate);
        return self::returnValue($res);
    }

    /**
     * 产品分析-数据统计
     * @param Request $request
     * @return array
     */
    public function dataStatistical(Request $request)
    {
        $prTypeArr = ["starVideo", "starLive", "qtaskVideo", "qtaskLive", "flowStarVideo", "flowStarLive", "flowQtaskVideo"];
        $validator = \Validator::make($request->all(),[
            'pr_type' => ['required', Rule::in($prTypeArr)],
            'st_date' => 'required|date_format:Y-m-d',
            'en_date' => 'required|date_format:Y-m-d',
            'cust_id' => 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $custId = $request->input('cust_id');
        $prType = $request->input('pr_type');
        $stDate = $request->input('st_date');
        $enDate = $request->input('en_date');

        $res = ProductService::dataStatistical($custId, $prType, $stDate, $enDate);
        return self::returnValue($res);
    }
}
