<?php

namespace App\Http\Controllers\Api\Data;

use App\Http\Controllers\Controller;
use App\Services\Data\SupplementOrderService;
use Illuminate\Http\Request;

class SupplementOrderController extends Controller
{
    # 助推订单停投
    public function supplementOrderStop(Request $request) {
        $validator = \Validator::make($request->all(),[
            'supplement_order_list'=> 'required',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $supplementOrderList = $request->input('supplement_order_list');// 流量助推订单信息列表
        $supplementOrderType = $request->input('supplement_order_type', 1);// 1星视频 2星直播 3星任务-视频

        list($res, $code) = SupplementOrderService::supplementOrderStop($supplementOrderList, $supplementOrderType);
        return self::returnValue($res, $code);
    }

    # 助推订单修改推广结束时间
    public function supplementOrderUpdatePromotionEndTime(Request $request) {
        $validator = \Validator::make($request->all(),[
            'advertiser_id' => 'required',
            'supplement_order_id'=> 'required',
            'promotion_end_time' => 'required|date_format:Y-m-d H:i:s',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $advertiserId = $request->input('advertiser_id');
        $supplementOrderId = $request->input('supplement_order_id');
        $promotionEndTime = $request->input('promotion_end_time');
        list($res, $code, $extra) = SupplementOrderService::supplementOrderUpdatePromotionEndTime($advertiserId, $supplementOrderId, $promotionEndTime);
        return self::returnValue($res, $code, $extra);
    }

    # 助推订单升单
    public function supplementOrderUpgradeAmount(Request $request) {
        $validator = \Validator::make($request->all(), [
            'advertiser_id' => 'required',
            'supplement_order_id' => 'required',
            'pay_method' => 'required|in:1,2,3,4',
            'amount' => 'required|integer|min:100'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $advertiserId = $request->input('advertiser_id');
        $supplementOrderId = $request->input('supplement_order_id');
        $payMethod = $request->input('pay_method');
        $amount = $request->input('amount');# 单位元

        list($res, $code, $extra) = SupplementOrderService::supplementOrderUpgradeAmount($advertiserId, $supplementOrderId, $payMethod, $amount);
        return self::returnValue($res, $code, $extra);
    }

    # 助推订单修改出价
    public function supplementOrderUpdateUnitPrice(Request $request) {
        $validator = \Validator::make($request->all(), [
            'advertiser_id' => 'required',
            'supplement_order_id' => 'required',
            'price' => 'required'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $advertiserId = $request->input('advertiser_id');
        $supplementOrderId = $request->input('supplement_order_id');
        $price = $request->input('price');# 单位元
        list($res, $code, $extra) = SupplementOrderService::supplementOrderUpdateUnitPrice($advertiserId, $supplementOrderId, $price);
        return self::returnValue($res, $code, $extra);
    }
}
