<?php

namespace App\Http\Controllers\Api\Sys;

use App\Http\Controllers\Controller;
use App\Services\Sys\CustomerService;
use Illuminate\Http\Request;

class CustomerController extends Controller
{
    /**
     * 行业信息列表
     * @return array
     */
    public function industryList()
    {
        $res = CustomerService::industryList();
        return self::returnValue($res);
    }

    /**
     * 客户列表
     * @return array
     */
    public function list(Request $request)
    {
        # 是否下拉
        $isSelect = $request->input('is_select', 0);
        $page     = $request->input('page', 1);
        $pageSize = $request->input('pageSize', 20);

        $advertiserId = $request->input('advertiserId');
        $nickName = $request->input('nickName');

        list($list, $total) = CustomerService::list($isSelect, $page, $pageSize, $advertiserId, $nickName);
        return self::returnPageValue($list, $total, $page, $pageSize);
    }

    /**
     * 客户操作
     * @param Request $request
     * @return array
     */
    public function operate(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'customer_id'   => 'nullable|int',
            'customer_name' => 'required|string',
            'industry_id'   => 'required|int',
            'remarks'       => 'nullable|string'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $customerId   = $request->input('customer_id');
        $customerName = $request->input('customer_name');
        $industryId   = $request->input('industry_id');
        $remarks      = $request->input('remarks');

        list($res, $code) = CustomerService::operate($customerId, $customerName, $industryId, $remarks);
        return self::returnValue($res, $code);
    }

    /**
     * 客户删除
     * @param Request $request
     * @return array
     */
    public function delete(Request $request) {
        $validator = \Validator::make($request->all(),[
            'customer_id'   => 'required|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $customerId = $request->input('customer_id');

        list($res, $code) = CustomerService::delete($customerId);
        return self::returnValue($res, $code);
    }

    /**
     * 添加授权账号
     * @param Request $request
     * @return array
     */
    public function accountAuth (Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'customer_id' => 'required|int',
            'nick_name'   => 'required|string'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $customerId = $request->input('customer_id');
        $nickName   = $request->input('nick_name');

        $res = CustomerService::accountAuth($customerId, $nickName);
        return self::returnValue($res);
    }

    /**
     * 账号删除
     * @param Request $request
     * @return array
     */
    public function accountDel(Request $request) {
        $validator = \Validator::make($request->all(),[
            'advertiser_id' => 'required|int'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 100);
        }

        $advertiserId = $request->input('advertiser_id');

        list($res, $code) = CustomerService::accountDel($advertiserId);
        return self::returnValue($res, $code);
    }


}
