<?php

namespace App\Http\Controllers\Api\Sys;

use App\Services\Sys\PermissionService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class PermissionController extends Controller
{
    /**
     * 权限树
     * @return array
     */
    public function permissionTree(Request $request)
    {
        $res = PermissionService::permissionTree();

        return self::returnValue($res);
    }

    /**
     * 用户拥有的权限树
     * @return array
     */
    public function userPermission(Request $request)
    {
        $admin_id = $request->input("admin_id");

        $res = PermissionService::userPermission($admin_id);

        return self::returnValue($res);
    }

    /**
     * 创建菜单
     * @param Request $request
     * @return array
     */
    public function createPermission(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'title' => 'required',
            'icon' => 'nullable',
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $title          = $request->input('title');
        $route          = $request->input('route','');
        $icon           = $request->input('icon');
        $parent_id      = $request->input('parent_id', 0);
        $weight         = time();   //时间戳，默认新增内容排放在最后

        list($res, $code)  = PermissionService::createPermission($parent_id,$title,$route,$weight,$icon);

        return self::returnValue($res, $code);
    }


    /***
     * 编辑权限
     * @param Request $request
     */
    public function editPermission(Request $request)
    {

        $validator = \Validator::make($request->all(),[
            'id' => 'required',
            'title' => 'required',
            'icon' => 'nullable',
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $id             = $request->input('id');
        $title          = $request->input('title');
        $route          = $request->input('route','');
        $icon           = $request->input('icon');

        list($res, $code)  = PermissionService::editPermission($id,$title,$route,$icon);

        return self::returnValue($res, $code);
    }

    /**
     * 对菜单进行排序设置
     * @param Request $request
     */
    public function beSort(Request $request)
    {

        $validator = \Validator::make($request->all(),[
            'p_id' => 'required|array',
            'parent_id'     => 'required',
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $parent_id      = $request->input('parent_id');
        $permission_id_arr = $request->input('p_id');

        $res = PermissionService::be_sort($parent_id,$permission_id_arr);
        return self::returnValue($res);
    }

    /**
     * 权限列表
     * @param Request $request
     * @return array
     */
    public function permissionList(Request $request)
    {

        $parent_id = $request->input('parent_id',0);
        $list =  PermissionService::permissionList($parent_id);

        return self::returnValue($list);
    }


    /**
     * 权限删除
     * @param Request $request
     * @return array
     */
    public function permissionDel(Request $request)
    {

        $id = $request->input('id', 0);
        $res = PermissionService::delPermission($id);

        return self::returnValue($res);
    }

    public function addRole(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'name' => 'required',
            'desc' => 'nullable',
            'permission_ids' => 'nullable|array',
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $name = $request->input('name');
        $desc = $request->input('desc','');
        $per_ids = $request->input('permission_ids');

        list($res, $code) = PermissionService::addRole($name,$desc,$per_ids);

        return self::returnValue($res, $code);
    }

    public function editRole(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'id' => 'required',
            'name' => 'required',
            'desc' => 'nullable',
            'permission_ids' => 'nullable|array',
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $id = $request->input('id');
        $name = $request->input('name');
        $desc = $request->input('desc','');
        $per_ids = $request->input('permission_ids');

        list($res, $code) = PermissionService::editRole($id,$name,$desc,$per_ids);

        return self::returnValue($res, $code);
    }

    public function delRole(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'id' => 'required',
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $id = $request->input('id');
        list($res, $code) = PermissionService::delRole($id);

        return self::returnValue($res, $code);
    }

    public function roleList(Request $request)
    {

        $data = PermissionService::roleList();

        return self::returnValue($data);
    }

    public function roleDetail(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'id' => 'required'
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $role_id = $request->input('id');
        $data = PermissionService::roleDetail($role_id);

        return self::returnValue($data);
    }

    public function addUser(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'name' => 'required|string',
            'password' => 'required|string',
            'desc' => 'nullable|string',
            'role_ids' => 'required|array',
            'advertiser_ids' => 'nullable|array',
            'cust_ids' => 'nullable|array',
            'group_id' => 'nullable|int'
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $name = $request->input('name');
        $password = $request->input('password');
        $desc = $request->input('desc');
        $role_ids = $request->input('role_ids');
        $advertiser_ids = $request->input('advertiser_ids');
        $cust_ids = $request->input('cust_ids');
        $group_id = $request->input('group_id');

        list($res, $code) = PermissionService::addUser($name,$password,$role_ids,$advertiser_ids,$desc,$cust_ids,$group_id);

        return self::returnValue($res, $code);
    }

    public function editUser(Request $request){
        $validator = \Validator::make($request->all(),[
            'id' => 'required',
            'name' => 'required|string',
            'password' => 'nullable|string',
            'desc' => 'nullable|string',
            'role_ids' => 'required|array',
            'advertiser_ids' => 'nullable|array',
            'cust_ids' => 'nullable|array',
            'group_id' => 'nullable|int'
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $id = $request->input('id');
        $name = $request->input('name');
        $password = $request->input('password');
        $desc = $request->input('desc');
        $role_ids = $request->input('role_ids');
        $advertiser_ids = $request->input('advertiser_ids');
        $cust_ids = $request->input('cust_ids');
        $group_id = $request->input('group_id');

        list($res, $code) = PermissionService::editUser($id,$name,$password,$role_ids,$advertiser_ids,$desc,$cust_ids,$group_id);

        return self::returnValue($res, $code);
    }

    public function delUser(Request $request){
        $validator = \Validator::make($request->all(),[
            'id' => 'required',
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $id = $request->input('id');
        list($res, $code) = PermissionService::delUser($id);

        return self::returnValue($res, $code);
    }

    public function userList(Request $request){
        $validator = \Validator::make($request->all(),[
            'page' => 'required|int',
            'pageSize' => 'nullable|int',
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $page = $request->input('page');
        $pageSize = $request->input('pageSize', 20);

        list($data, $total) = PermissionService::userList($page, $pageSize);

        return self::returnPageValue($data, $total, $page, $pageSize);
    }

    public function userDetail(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'id' => 'required|int'
        ]);
        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $id = $request->input('id');
        $data = PermissionService::userDetail($id);

        return self::returnValue($data);
    }

    public function adverList(Request $request)
    {
        $data = PermissionService::adverList();

        return self::returnValue($data);
    }

    /**
     * 系统登录
     * @param Request $request
     * @return array
     */
    public function login(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'username' => 'required',
            'password' => 'required'
        ],[
            'username.required' => '账户必填',
            'password.required' => '密码必填'
        ]);

        if ($validator->fails()) {
            return self::returnValue($validator->getMessageBag(), 1102);
        }

        $username = $request->input('username');
        $password = $request->input('password');

        list($data, $code) = PermissionService::doLogin($username, $password);

        return self::returnValue($data, $code);
    }



}


