<?php

namespace App\Http\Middleware;

use App\Models\Sys\SysUsers;
use App\Models\Sys\SysUserLog;
use App\Models\Sys\SysUserAdver;
use App\Models\Sys\SysUserCusts;
use App\Models\Sys\SysCustomerAdver;
use App\Models\Sys\SysCustomer;
use App\Models\JuxingAdAccount;
use Illuminate\Http\Response;
use Illuminate\Http\Request;
use Closure;
use App\Support\RedisModel;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class ApiLoginMiddleware
{
    public function handle(Request $request, Closure $next)
    {
        $userId = $request->input('admin_id');
        $ttl = $request->input('ttl');
        $sign = $request->input('sign');

        $redisKey = env('LOGIN_REDIS_KEY') . '-'. $userId;
        $randomKey = RedisModel::get($redisKey);
        if(!$randomKey){
            $data = Controller::returnValue(['data' => '请重新登录'],4002, '登录失败，请重新登录');
            return new Response($data);
        }

        // 用户
        $user = SysUsers::query()->find($userId);
        if (empty($user)) {
            $data = Controller::returnValue(['data' => '请重新登录'],4002, '登录失败，请重新登录');
            return new Response($data);
        }

        if(SysUsers::validSign($userId, $ttl, $randomKey, $sign) === false){
            $data = Controller::returnValue(['data' => '登录失败，请重新登录'],4002, '登录失败，请重新登录');
            return new Response($data);
        }

        #获取分配广告主，客户信息
        list($custIds, $adverIds) = $this->getCusts($userId);
        $user->custIds = $custIds;
        $user->adverIds = $adverIds;

        // 用户信息写如Auth对象
        Auth::setUser($user);

        if(env('IF_RECORD_ULOG')){
            // 当前后端路由
            $currentRoute = app('request')->route()->uri();
            // 当前路由对应的权限列表
            $currentRoute = strstr($currentRoute, 'api/');

            self::userActionRecord($currentRoute, $userId, $request->all());
        }

        return $next($request);
    }

    private function getCusts($userId)
    {
        #获取客户
        $cust_ids = SysCustomer::where('enable', 1)->pluck('id')->all();
        if($userId != 1 ){
            $cust_ids = SysUserCusts::whereIn('customer_id', $cust_ids)->where('sys_user_id', $userId)->where('enable', 1)->pluck('customer_id')->all();
        }

        #获取广告主
        $adver_ids = JuxingAdAccount::where('enable', 1)->pluck('advertiser_id')->all();
        if($userId != 1 ){
            $adver_ids = SysCustomerAdver::whereIn('customer_id', $cust_ids)->where('enable', 1)->pluck('advertiser_id')->all();
        }

        return [$cust_ids, $adver_ids];

    }

    private function userActionRecord($route, $userId, $params)
    {
        $apiInfos = config('apilist');

        $apis = array_keys($apiInfos);

        if(!in_array($route, $apis)){
            return ;
        }

        $log = new SysUserLog();
        $log->user_id = $userId;
        $log->route = $route;
        $log->note = $apiInfos[$route];
        $log->params = json_encode($params);

        $log->save();
    }


}
