<?php

namespace kwaiSDK\Api;

use App\Support\Curl;
use App\Support\Log;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\RequestException;
use kwaiSDK\Exceptions\Exception;

class Request
{
    protected $appId       = '';
    protected $secret      = '';
    protected $accessToken = '';
    protected $host        = '';
    protected $apiPre      = '';
    protected $type        = '';
    protected $path        = '';
    protected $headers     = [];
    protected $options     = [];
    protected $data        = [];

    public function __construct(array $conf)
    {
        $this->host        = $conf['host'] ?? null;
        $this->options     = $conf['options'] ?? [];
        $this->apiPre      = $conf['api_pre'] ?? null;
        $this->appId       = $conf['app_id'] ?? null;
        $this->secret      = $conf['secret'] ?? null;
        $this->accessToken = $conf['access_token'] ?? null;

    }

    /**
     * 初始化配置
     * */
    protected function initSet(){
        $this->headers();
        $this->options();
        $this->reqset();
    }

    /**
     * 设置header
     */
    protected function headers(){
        $this->headers=[
            'Content-Type' => 'application/json'
        ];
    }

    /**
     * 设置其他参数
     */
    protected function options(){
        if (isset($this->options['headers']))
            $this->headers = array_merge($this->headers, $this->options['headers']);
    }

    /**
     * 请求配置
     */
    protected function reqset()
    {
        if (isset($this->appId, $this->secret)) {
            $this->data['app_id'] = $this->appId;
            $this->data['secret'] = $this->secret;
        }

        if (isset($this->accessToken)) {
            $this->headers['Access-Token'] = $this->accessToken;
        }
    }

    /**
     * 请求调用
     * */
    protected function send(){
        $client = new Client([
            'verify' => false
        ]);

        $url = $this->host.$this->apiPre.$this->path;
        $this->options['headers'] = $this->headers;

        if (!empty($this->data)) {
            if ($this->type == 'GET') {
                $url .= ('?'.http_build_query($this->data));
            } else {
                $this->options['body'] = json_encode($this->data);
            }
        }

        Log::info('api请求记录', [
            'type'     => $this->type,
            'url'      => $url,
            'options'  => $this->options
        ], 'kwaiSDK-api');

        $response = $client->request($this->type, $url, $this->options);
        /*Log::info('api请求记录', [
            'type'     => $this->type,
            'url'      => $url,
            'options'  => $this->options,
//            'response' => $response
        ], 'kwaiSDK-api');*/

        return $response->getBody()->getContents();
    }

    /**
     * 请求调用
     * */
    protected function sendV2(){
        $url = $this->host.$this->apiPre.$this->path;

        Log::info('api请求记录', [
            'type'     => $this->type,
            'url'      => $url,
            'options'  => [
                'headers' => $this->headers,
                'body'    => $this->data
            ]
        ], 'kwaiSDK-api');

        if ($this->type == 'GET') {
            if (!empty($this->data)) $url .= ('?'.http_build_query($this->data));

            $response = Curl::get($url, $this->headers);
        } else {
            $response = Curl::post($url, $this->data, $this->headers);
        }

        return $response;
    }

    /**
     * 执行操作
     * @return mixed
     */
    protected function exec(){
        $this->initSet();

        try {
            return json_decode($this->sendV2(),true);
        } catch (RequestException $e){
            if (empty($e->getResponse()) || $e->getResponse()==null)
                throw new Exception(json_encode(['_message'=>'system error']));

            if (method_exists($e->getResponse(),'getBody')){
                $contents = $e->getResponse()->getBody()->getContents();

                $temp = json_decode($contents,true);
                if (!empty($temp)) {
                    $temp['_method']  = $this->type;
                    $temp['_url']     = $this->host.$this->path;
                } else {
                    $temp['_message'] = $e->getMessage();
                }
            } else {
                $temp['_message'] = $e->getMessage();
            }

            $temp['_httpcode'] = $e->getCode();

            throw new Exception(json_encode($temp));
        }
    }
}
