<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});


Route::group(['namespace' => '\App\Http\Controllers\Api'], function () {

	#登录
	Route::any('login', 'Sys\PermissionController@login');

	Route::group(['middleware' => ['api.login']], function () {

		Route::group(['prefix'=>'sys'],function() {
			Route::get('permissionTree', 'Sys\PermissionController@permissionTree');
			Route::get('userPermission', 'Sys\PermissionController@userPermission');
			Route::post('createPermission', 'Sys\PermissionController@createPermission');
			Route::post('editPermission', 'Sys\PermissionController@editPermission');
			Route::post('beSort', 'Sys\PermissionController@beSort');
			Route::post('permissionDel', 'Sys\PermissionController@permissionDel');
			Route::get('permissionList', 'Sys\PermissionController@permissionList');

			Route::post('addRole', 'Sys\PermissionController@addRole');
			Route::post('editRole', 'Sys\PermissionController@editRole');
			Route::post('delRole', 'Sys\PermissionController@delRole');
			Route::get('roleList', 'Sys\PermissionController@roleList');
			Route::get('roleDetail', 'Sys\PermissionController@roleDetail');

			Route::post('addUser', 'Sys\PermissionController@addUser');
			Route::post('editUser', 'Sys\PermissionController@editUser');
			Route::post('delUser', 'Sys\PermissionController@delUser');
			Route::get('userList', 'Sys\PermissionController@userList');
			Route::get('userDetail', 'Sys\PermissionController@userDetail');

			# 客户列表
            Route::get('customerList', 'Sys\CustomerController@list');
            # 客户操作(添加和编辑)
            Route::post('customerOperate', 'Sys\CustomerController@operate');
            # 客户删除
            Route::post('customerDelete', 'Sys\CustomerController@delete');
            # 账号授权
            Route::post('accountAuth', 'Sys\CustomerController@accountAuth');
            # 账号删除
            Route::post('accountDel', 'Sys\CustomerController@accountDel');
		});

		# 广告主下拉列表
		Route::get('adverList', 'Sys\PermissionController@adverList');
        # 行业信息下拉列表
        Route::get('industryList', 'Sys\CustomerController@industryList');

        Route::group(['prefix' => 'supplement_order'], function() {
            # 助推订单停投
            Route::post('stop', 'Data\SupplementOrderController@supplementOrderStop');
            # 助推订单修改推广结束时间
            Route::post('updatePromotionEndTime', 'Data\SupplementOrderController@supplementOrderUpdatePromotionEndTime');
            # 助推订单升单
            Route::post('upgradeAmount', 'Data\SupplementOrderController@supplementOrderUpgradeAmount');
            # 助推订单修改出价
            Route::post('updateUnitPrice', 'Data\SupplementOrderController@supplementOrderUpdateUnitPrice');
        });

	    Route::group(['prefix'=>'stat'],function() {

	    	#达人排行-视频
	        Route::get('redVideoRank', 'Data\DataStatController@redVideoRank');
	        #达人排行-直播
	        Route::get('redLiveRank', 'Data\DataStatController@redLiveRank');
	        #消耗数据-汇总
	        Route::get('costDataTotal', 'Data\DataStatController@costDataTotal');
	        #消耗数据-分客户列表
	        Route::get('custCostList', 'Data\DataStatController@custCostList');
	        #流量助推-客户分析
	        Route::get('custFlowVideoList', 'Data\DataStatController@custFlowVideoList');
	        Route::get('custFlowVideoDetails', 'Data\DataStatController@custFlowVideoDetails');
	        Route::get('custFlowVideoUserDetails', 'Data\DataStatController@custFlowVideoUserDetails');
	        Route::get('custFlowLiveList', 'Data\DataStatController@custFlowLiveList');
            Route::get('custFlowLiveDetails', 'Data\DataStatController@custFlowLiveDetails');
            Route::get('custFlowLiveUserDetails', 'Data\DataStatController@custFlowLiveUserDetails');
            #流量助推-行业分析
            Route::get('industryFlowVideoList', 'Data\DataStatController@industryFlowVideoList');
            Route::get('industryFlowVideoDetails', 'Data\DataStatController@industryFlowVideoDetails');
            Route::get('industryFlowVideoCustDetails', 'Data\DataStatController@industryFlowVideoCustDetails');
            Route::get('industryFlowLiveList', 'Data\DataStatController@industryFlowLiveList');
            Route::get('industryFlowLiveDetails', 'Data\DataStatController@industryFlowLiveDetails');
            Route::get('industryFlowLiveCustDetails', 'Data\DataStatController@industryFlowLiveCustDetails');

            #助推订单
            Route::get('supplementOrderList', 'Data\DataStatController@supplementOrderList');

            #流量助推-实时数据，分日
            Route::get('svfDailyData', 'Data\DataStatController@svfDailyData');
            Route::get('svfDailyUserData', 'Data\DataStatController@svfDailyUserData');
            Route::post('svfDataUp', 'Data\DataStatController@svfDataUp');

            #快任务-视频分日
            Route::get('qtaskVideoDailyData', 'Data\DataStatController@qtaskVideoDailyData');
            Route::get('qtaskVideoTaskDailyData', 'Data\DataStatController@qtaskVideoTaskDailyData');
            Route::get('qtaskVideoOrderDailyData', 'Data\DataStatController@qtaskVideoOrderDailyData');

            #快任务-直播分日
            Route::get('qtaskLiveDailyData', 'Data\DataStatController@qtaskLiveDailyData');
            Route::get('qtaskLiveTaskDailyData', 'Data\DataStatController@qtaskLiveTaskDailyData');
            Route::get('qtaskLiveOrderDailyData', 'Data\DataStatController@qtaskLiveOrderDailyData');

            #快任务视频-行业分析
            Route::get('industryQtaskVideoList', 'Data\DataStatController@industryQtaskVideoList');
            Route::get('industryQtaskVideoDetails', 'Data\DataStatController@industryQtaskVideoDetails');
            Route::get('industryQtaskVideoCustDetails', 'Data\DataStatController@industryQtaskVideoCustDetails');
            #快任务直播-行业分析
            Route::get('industryQtaskLiveList', 'Data\DataStatController@industryQtaskLiveList');
            Route::get('industryQtaskLiveDetails', 'Data\DataStatController@industryQtaskLiveDetails');
            Route::get('industryQtaskLiveCustDetails', 'Data\DataStatController@industryQtaskLiveCustDetails');
            #快任务视频-客户分析
            Route::get('custQtaskVideoList', 'Data\DataStatController@custQtaskVideoList');
            Route::get('custQtaskVideoDetails', 'Data\DataStatController@custQtaskVideoDetails');
            Route::get('custQtaskVideoUserDetails', 'Data\DataStatController@custQtaskVideoUserDetails');
            #快任务直播-客户分析
            Route::get('custQtaskLiveList', 'Data\DataStatController@custQtaskLiveList');
            Route::get('custQtaskLiveDetails', 'Data\DataStatController@custQtaskLiveDetails');
            Route::get('custQtaskLiveUserDetails', 'Data\DataStatController@custQtaskLiveUserDetails');

            # 分时数据趋势
            Route::get('svfHourDataCure', 'Data\DataStatController@svfHourDataCure');
            # 分时数据对比
            Route::post('svfHourDataContrast', 'Data\DataStatController@svfHourDataContrast');
	    });

	    # 产品分析
        Route::group(['prefix'=>'product'],function() {
            # 消耗汇总
            Route::get('dataSummary', 'Data\ProductController@dataSummary');
            # 数据统计
            Route::get('dataStatistical', 'Data\ProductController@dataStatistical');
        });

        # 客户分析
        Route::group(['prefix'=>'customer'],function() {
            # 消耗汇总和曲线
            Route::get('summaryTrend', 'Data\CustomerController@summaryTrend');
            # 数据列表
            Route::get('dataList', 'Data\CustomerController@dataList');
        });

        # 自定义字段
        Route::group(['prefix'=>'searchConfig'], function() {
            Route::get('configCheck', 'Data\SearchConfigController@configCheck');
            Route::get('configInfo', 'Data\SearchConfigController@configInfo');
            Route::get('groupList', 'Data\SearchConfigController@groupList');
            Route::post('groupAdd', 'Data\SearchConfigController@groupAdd');
            Route::post('groupEdit', 'Data\SearchConfigController@groupEdit');
            Route::post('groupApply', 'Data\SearchConfigController@groupApply');

            Route::get('configDetail', 'Data\SearchConfigController@configDetail');
            Route::post('confEdit', 'Data\SearchConfigController@confEdit');
        });

        # 达人库
        Route::group(['prefix'=>'starLibrary'], function() {
            # 达人信息导入
            Route::post('infoUpload', 'Sys\StarLibraryController@infoUpload');
            # 达人机构导入
            Route::post('instUpload', 'Sys\StarLibraryController@instUpload');
            # 类别列表
            Route::get('category', 'Sys\StarLibraryController@category');
            # 达人信息列表
            Route::get('infoList', 'Sys\StarLibraryController@infoList');
            # 达人机构列表
            Route::get('instList', 'Sys\StarLibraryController@instList');
            # 达人库上传记录
            Route::get('upList', 'Sys\StarLibraryController@upList');

            # 用户组列表
            Route::get('groupList', 'Sys\StarLibraryController@groupList');
            # 用户组添加
            Route::post('groupAdd', 'Sys\StarLibraryController@groupAdd');
            # 用户组编辑
            Route::post('groupEdit', 'Sys\StarLibraryController@groupEdit');
            # 用户组删除
            Route::post('groupDel', 'Sys\StarLibraryController@groupDel');
        });
	});

    # 我的任务
    Route::group(['prefix'=>'task'],function() {
        # 星视频列表
        Route::post('starVideoList', 'Data\TaskController@starVideoList');
    });

    # 助推订单批量创建
    Route::group(['prefix'=>'supplementOrder'],function() {
        # 配置助推订单批量创建任务
        Route::post('setCreateTask', 'Data\TaskController@setCreateTask');
        # 配置助推订单批量创建的任务列表
        Route::get('taskList', 'Data\TaskController@taskList');
        # 获取批量创建助推订单的配置详情
        Route::get('taskDetail', 'Data\TaskController@taskDetail');
        # 获取配置自动生成的助推订单信息
        Route::get('list', 'Data\TaskController@orderList');
        # 停用批量创建配置
        Route::get('stopConfig', 'Data\TaskController@stopConfig');
    });

    Route::group(['middleware' => ['h5.verify']], function () {
        Route::any('kx/signRecords', 'Kx\DataController@signRecords');
    });

    Route::any('kx/exportRecords', 'Kx\DataController@exportRecords');

    #url模拟点击
    Route::any('kx/urlSimulateClick', 'Kx\DataController@urlSimulateClick');

    Route::any('kx/addLuckyInfo', 'Kx\DataController@addLuckyInfo');
    Route::any('kx/luckyDraw', 'Kx\DataController@luckyDraw');
    #抽奖记录
    Route::any('kx/exportLucky', 'Kx\DataController@exportLuckyRecords');

});
